package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallPurchaseNotes;
import com.ruoyi.mall.service.IMallPurchaseNotesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 购买须知Controller
 * 
 * @author ruoyi
 * @date 2022-07-06
 */
@RestController
@RequestMapping("/mall/mallPurchaseNotes")
public class MallPurchaseNotesController extends BaseController
{
    @Autowired
    private IMallPurchaseNotesService mallPurchaseNotesService;

    /**
     * 查询购买须知列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallPurchaseNotes mallPurchaseNotes)
    {
        startPage();
        List<MallPurchaseNotes> list = mallPurchaseNotesService.selectMallPurchaseNotesList(mallPurchaseNotes);
        return getDataTable(list);
    }

    /**
     * 导出购买须知列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:export')")
    @Log(title = "购买须知", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallPurchaseNotes mallPurchaseNotes)
    {
        List<MallPurchaseNotes> list = mallPurchaseNotesService.selectMallPurchaseNotesList(mallPurchaseNotes);
        ExcelUtil<MallPurchaseNotes> util = new ExcelUtil<MallPurchaseNotes>(MallPurchaseNotes.class);
        return util.exportExcel(list, "购买须知数据");
    }

    /**
     * 获取购买须知详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(mallPurchaseNotesService.selectMallPurchaseNotesById(id));
    }

    /**
     * 新增购买须知
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:add')")
    @Log(title = "购买须知", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallPurchaseNotes mallPurchaseNotes)
    {
        return toAjax(mallPurchaseNotesService.insertMallPurchaseNotes(mallPurchaseNotes));
    }

    /**
     * 修改购买须知
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:edit')")
    @Log(title = "购买须知", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallPurchaseNotes mallPurchaseNotes)
    {
        return toAjax(mallPurchaseNotesService.updateMallPurchaseNotes(mallPurchaseNotes));
    }

    /**
     * 删除购买须知
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPurchaseNotes:remove')")
    @Log(title = "购买须知", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(mallPurchaseNotesService.deleteMallPurchaseNotesByIds(ids));
    }
}
